@@ -1,6 +1,4 @@
-
-from enum import IntEnum as _IntEnum
-
+from enum import IntEnum as _IntEnum, Enum as _Enum
 
 try:
     from ssl import PROTOCOL_TLS
@@ -20,7 +18,7 @@ except ImportError:
     PROTOCOL_TLSv1 = 3
 
 try:
-    from ssl import VerifyMode, SSLError
+    from ssl import VerifyMode, SSLError, Purpose, _ASN1Object
 except ImportError:
 
     class VerifyMode(_IntEnum):
@@ -30,4 +28,14 @@ except ImportError:
 
     class SSLError(OSError):
         library: str
-        reason: str
\ No newline at end of file
+        reason: str
+
+    class Purpose(str, _Enum):
+        """SSLContext purpose flags with X509v3 Extended Key Usage objects"""
+
+        SERVER_AUTH = "1.3.6.1.5.5.7.3.1"
+        CLIENT_AUTH = "1.3.6.1.5.5.7.3.2"
+
+        @property
+        def oid(self):
+            return self
